@@ -33,17 +33,13 @@ class mutation_parameters:
             mu: 
             F:
             C:
-            min_parents = 0.1
-            max_parents = 0.9
     """
     mutation_type: de_mutation_type = field(repr=True,default=de_mutation_type.de_rand_1_bin)
     sigma: float = field(repr=True,default=0.2)
     mu: float = field(repr=True,default=0.02)
     F: float = field(repr=True,default=0.6)
     C: float = field(repr=True,default=0.8)
-    min_parents:int = field(repr=True,default=2)
-    max_parents:int = field(repr=True,default=10)
-
+    
 def get_eval_param_matrix(individuals:List[Individual]):    
     pop = np.zeros((len(individuals),len(individuals[0].eval_parameters)))
     xmin = individuals[0].eval_parameter_min
@@ -52,6 +48,12 @@ def get_eval_param_matrix(individuals:List[Individual]):
         pop[i,:] = ind.eval_parameters
     return pop,xmin,xmax
 
+def get_objective_matrix(individuals:List[Individual]):    
+    pop = np.zeros((len(individuals),len(individuals[0].objectives)))
+    for i,ind in enumerate(individuals):
+        pop[i,:] = ind.objectives
+    return pop
+
 def shuffle_population(pop,nIndividuals,nparents):
     index = (1+np.random.permutation(nIndividuals))[0:nparents]     # Pick Random Parents
     rot = convert_to_ndarray([range(0,nIndividuals)])
@@ -66,7 +68,7 @@ def shuffle_population(pop,nIndividuals,nparents):
         pop_shuffled.append(pop[a[:,i]])                            # List of shuffled population
     return pop_shuffled
 
-def de_best_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_parameters:List[Parameter],performance_parameters:List[Parameter],min_parents:int,max_parents:int,F:float, C:float):
+def de_best_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_parameters:List[Parameter],performance_parameters:List[Parameter],min_parents:int,max_parents:int=2,F:float=0.6, C:float=0.7):
     """
         Applies mutation and crossover using de_1_rand_bin to a list of individuals 
         Inputs:
@@ -115,7 +117,7 @@ def de_best_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_p
 
     return newIndividuals 
 
-def de_rand_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_parameters:List[Parameter],performance_parameters:List[Parameter],min_parents:int,max_parents:int,F:float, C:float):
+def de_rand_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_parameters:List[Parameter],performance_parameters:List[Parameter],min_parents:int=3,max_parents:int=3,F:float=0.6, C:float=0.7):
     """
         Applies mutation and crossover using de_rand_1_bin to a list of individuals 
         Inputs:
@@ -131,13 +133,10 @@ def de_rand_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_p
     """ 
     nIndividuals = len(individuals)
     pop,xmin,xmax = get_eval_param_matrix(individuals)
-    
-    min_parents = max([3,min_parents])
-    max_parents = max([3,max_parents])
-    nparents = random.randint(min_parents,max_parents) 
+        
     nEvalParams = len(individuals[0].eval_parameters)
     #-------------- Mutation --------------
-    pop_shuffled = shuffle_population(pop,nIndividuals,nparents)
+    pop_shuffled = shuffle_population(pop,nIndividuals,max_parents)
     pop_rand = pop_shuffled.pop()
     # Generate the new mutated population
     temp = pop*0
@@ -163,7 +162,8 @@ def de_rand_1_bin(individuals:List[Individual],objectives:List[Parameter],eval_p
         newIndividuals.append(Individual(eval_parameters=set_eval_parameters(eval_parameters,z),objectives=objectives,performance_parameters=performance_parameters))
     return newIndividuals 
 
-def mutation_simple(self,individuals:List[Individual],nCrossover:int,nMutation:int,objectives:List[Parameter],eval_parameters:List[Parameter],performance_parameters:List[Parameter],mu:float,sigma:float):
+
+def simple(individuals:List[Individual],nCrossover:int,nMutation:int,objectives:List[Parameter],eval_parameters:List[Parameter],performance_parameters:List[Parameter],mu:float,sigma:float):
     """
         Performs a simple mutation and crossover on the individuals
         Inputs:
@@ -187,9 +187,9 @@ def mutation_simple(self,individuals:List[Individual],nCrossover:int,nMutation:i
         
         crossover_individuals.append(Individual(eval_parameters=set_eval_parameters(eval_parameters,y1_new),objectives=objectives,performance_parameters=performance_parameters))        
         crossover_individuals.append(Individual(eval_parameters=set_eval_parameters(eval_parameters,y2_new),objectives=objectives,performance_parameters=performance_parameters))
-
-    # Perform Mutation
-    mutation_individuals = []
+    
+    # Perform Mutation    
+    mutation_individuals = list()
     for k in range(nMutation):
         rand_indx = np.random.randint(0,nIndividuals-1)
         y1 = individuals[rand_indx].eval_parameters
@@ -225,7 +225,7 @@ def mutate(x1:np.ndarray,xmin:ndarray,xmax:ndarray,mu:float=0.02,sigma:float=0.2
                 y[indx]=xmin[indx]
             if (xmax is not None) and (y[indx]>xmax[indx]):
                 y[indx]=xmax[indx]
-    return ys
+    return y
 
 def crossover(x1:np.ndarray,x2:np.ndarray):
     '''
