@@ -11,7 +11,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 from ..helpers import Parameter
 from ..base_classes import Optimizer, Individual
-from ..nsga3.mutate import de_best_1_bin,de_rand_1_bin, mutation_parameters, de_mutation_type
+from ..nsga3.mutate import de_best_1_bin,de_rand_1_bin, mutation_parameters, de_mutation_type, simple
 from random import seed, gauss, random, randint
 from tqdm import trange
 
@@ -124,15 +124,15 @@ class SODE(Optimizer):
         num_params = len(individuals[0].eval_parameters)        
         if self.mutation_params.mutation_type == de_mutation_type.de_best_1_bin:
             newIndividuals = de_best_1_bin(individuals=individuals,objectives=self.objectives,
-                min_parents=self.mutation_params.min_parents,max_parents=self.mutation_params.max_parents,
                 eval_parameters=self.eval_parameters,performance_parameters=self.performance_parameters,
                 F=self.mutation_params.F,C=self.mutation_params.C)
         elif self.mutation_params.mutation_type == de_mutation_type.de_rand_1_bin:
             newIndividuals = de_rand_1_bin(individuals=individuals,objectives=self.objectives,
-                min_parents=self.mutation_params.min_parents,max_parents=self.mutation_params.max_parents,
                 eval_parameters=self.eval_parameters,performance_parameters=self.performance_parameters,
                 F=self.mutation_params.F,C=self.mutation_params.C)
         elif self.mutation_params.mutation_type == de_mutation_type.simple:
-            newIndividuals = mutation_simple(individuals=individuals,nCrossover=nParents,nMutation=nParents,objectives=self.objectives,eval_parameters=self.eval_parameters,performance_parameters=self.performance_parameters,mu=self.mutation_params.mu,sigma=self.mutation_params.sigma)
+            nCrossover = int(self.pop_size/2)
+            nMutation = self.pop_size-nCrossover
+            newIndividuals = simple(individuals=individuals,nCrossover=nCrossover,nMutation=nMutation,objectives=self.objectives,eval_parameters=self.eval_parameters,performance_parameters=self.performance_parameters,mu=self.mutation_params.mu,sigma=self.mutation_params.sigma)
 
         return newIndividuals
\ No newline at end of file
